@@ -2,5 +2,5 @@ from .file_utils import (open_file)
 from .core_utils import (refresh, _selected_rows, select_all_by_type, move_window, control_window, close_selected, activate_window)
 from .update_utils import (update_table, update_monitor_dropdown)
 from .build_ui import (_build_ui)
-from .wmctrl_utils import (get_monitors, get_windows)
+from .wmctrl_utils import (get_monitors, get_windows, _compute_self_ids)
 from .command_utils import (run_command)
