@@ -11,8 +11,9 @@ class windowManagerConsole(QMainWindow):
         self.setWindowTitle("Window Manager")
         self.resize(980, 640)
         self.monitors: List[Tuple[str, int, int, int, int]] = []
-        self.windows: List[Tuple[str, str, str, str, str]] = []  # incl. type
+        self.windows:  List[Tuple[str, str, str, str, str]] = []
         self._build_ui()
+        self._compute_self_ids()  # <-- compute once up front
         self.refresh()
 
 windowManagerConsole = initFuncs(windowManagerConsole)
